@@ -13,6 +13,7 @@ except:
     print("No imswitch available")
     IS_IMSWITCH = False
 
+import requests
 
 class UC2Client(object):
     # headers = {'ESP32-version': '*'}
@@ -90,6 +91,8 @@ class UC2Client(object):
             from .wifi import Wifi
             from .camera import Camera
             from .analog import Analog
+            from .updater import updater
+            from .modules import Modules
 
 
         #FIXME
@@ -134,7 +137,13 @@ class UC2Client(object):
         # initialize config
         self.config = config(self)
         self.pinConfig = self.config.loadConfigDevice()
-
+        
+        # initialize updater 
+        self.updater = updater(parent=self)
+        
+        # initialize module controller
+        self.modules = Modules(parent=self)
+   
     def post_json(self, path, payload, getReturn=True, timeout=1):
         if self.is_wifi:
             # FIXME: this is not working
